# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import user_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/RegisterUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.FromString,
                )
        self.DeactivateUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeactivateUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.FromString,
                )
        self.ActivateUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/ActivateUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.FromString,
                )
        self.CreateAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/CreateAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.FromString,
                )
        self.GetAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.FromString,
                )
        self.GetAPITokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAPITokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.FromString,
                )
        self.DeleteAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeleteAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.FromString,
                )
        self.DeleteAPITokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeleteAPITokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
                )
        self.UpdateUserDisplayName = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/UpdateUserDisplayName',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.FromString,
                )
        self.UpdateUserEmail = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/UpdateUserEmail',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.FromString,
                )
        self.GetUserProjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetUserProjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.FromString,
                )
        self.GetNotActivatedUsers = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetNotActivatedUsers',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.FromString,
                )
        self.GetAllUsers = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAllUsers',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.FromString,
                )


class UserServiceServicer(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    def RegisterUser(self, request, context):
        """RegisterUser

        Status: STABLE

        This request should be called when a new user logs in for the first time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateUser(self, request, context):
        """DeActivateUser 

        Status: ALPHA

        This deactivates a specific user (Admin request)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateUser(self, request, context):
        """ActivateUser 

        Status: STABLE

        This activates a specific user (Admin request)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAPIToken(self, request, context):
        """CreateAPIToken

        Status: STABLE

        Creates an API token to authenticate
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAPIToken(self, request, context):
        """GetAPIToken

        Status: STABLE

        Returns one API token by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAPITokens(self, request, context):
        """GetAPITokens

        Status: STABLE

        Returns a list of API tokens for a specific user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAPIToken(self, request, context):
        """DeleteAPIToken

        Status: STABLE

        Deletes the specified API Token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAPITokens(self, request, context):
        """DeleteAPITokens

        Status: STABLE

        Deletes the specified API Token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """GetUserRequest

        Status: STABLE

        This is a request that returns the user information of the
        current user or if invoked by an admin from another user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserDisplayName(self, request, context):
        """UpdateUserDisplayName

        Status: STABLE

        Updates the Displayname for the user (Personal only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserEmail(self, request, context):
        """UpdateUserDisplayName

        Status: ALPHA

        Updates the email for the user (Personal only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserProjects(self, request, context):
        """GetUserProjects

        Status: STABLE

        Gets all project_ids a user is member of
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotActivatedUsers(self, request, context):
        """GetNotActivatedUsers

        Status: STABLE

        Get all not activated users (Admin only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllUsers(self, request, context):
        """GetAllUsers

        Status: ALPHA

        Get all users inkluding permissions (Admin only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.SerializeToString,
            ),
            'DeactivateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.SerializeToString,
            ),
            'ActivateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.SerializeToString,
            ),
            'CreateAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.SerializeToString,
            ),
            'GetAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.SerializeToString,
            ),
            'GetAPITokens': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAPITokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.SerializeToString,
            ),
            'DeleteAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.SerializeToString,
            ),
            'DeleteAPITokens': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAPITokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.SerializeToString,
            ),
            'UpdateUserDisplayName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserDisplayName,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.SerializeToString,
            ),
            'UpdateUserEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserEmail,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.SerializeToString,
            ),
            'GetUserProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.SerializeToString,
            ),
            'GetNotActivatedUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotActivatedUsers,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.SerializeToString,
            ),
            'GetAllUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllUsers,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    @staticmethod
    def RegisterUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/RegisterUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeactivateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeactivateUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/ActivateUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/CreateAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAPITokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAPITokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeleteAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAPITokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeleteAPITokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserDisplayName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/UpdateUserDisplayName',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/UpdateUserEmail',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetUserProjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotActivatedUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetNotActivatedUsers',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAllUsers',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
