# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.internal.v1 import authorize_pb2 as aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2


class InternalAuthorizeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Authorize = channel.unary_unary(
                '/aruna.api.internal.v1.InternalAuthorizeService/Authorize',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.FromString,
                )
        self.GetSecret = channel.unary_unary(
                '/aruna.api.internal.v1.InternalAuthorizeService/GetSecret',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.FromString,
                )


class InternalAuthorizeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Authorize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalAuthorizeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Authorize': grpc.unary_unary_rpc_method_handler(
                    servicer.Authorize,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.internal.v1.InternalAuthorizeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalAuthorizeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Authorize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalAuthorizeService/Authorize',
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalAuthorizeService/GetSecret',
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
