# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import object_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2


class ObjectServiceStub(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitializeNewObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/InitializeNewObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.FromString,
                )
        self.GetUploadURL = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetUploadURL',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.FromString,
                )
        self.GetDownloadURL = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetDownloadURL',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.FromString,
                )
        self.GetDownloadLinksBatch = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetDownloadLinksBatch',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.FromString,
                )
        self.CreateDownloadLinksStream = channel.unary_stream(
                '/aruna.api.storage.services.v1.ObjectService/CreateDownloadLinksStream',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.FromString,
                )
        self.FinishObjectStaging = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/FinishObjectStaging',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.FromString,
                )
        self.UpdateObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/UpdateObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.FromString,
                )
        self.CreateObjectReference = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CreateObjectReference',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.FromString,
                )
        self.CloneObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CloneObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.FromString,
                )
        self.DeleteObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/DeleteObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.FromString,
                )
        self.DeleteObjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/DeleteObjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.FromString,
                )
        self.GetObjectByID = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectByID',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.FromString,
                )
        self.GetObjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.FromString,
                )
        self.GetObjectRevisions = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectRevisions',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.FromString,
                )
        self.GetLatestObjectRevision = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetLatestObjectRevision',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.FromString,
                )
        self.GetObjectEndpoints = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectEndpoints',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.FromString,
                )
        self.AddLabelsToObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/AddLabelsToObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.FromString,
                )
        self.SetHooksOfObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/SetHooksOfObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.FromString,
                )
        self.GetReferences = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetReferences',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.FromString,
                )
        self.GetObjectPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.FromString,
                )
        self.GetObjectPaths = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectPaths',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.FromString,
                )
        self.CreateObjectPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/CreateObjectPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.FromString,
                )
        self.SetObjectPathVisibility = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/SetObjectPathVisibility',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.FromString,
                )
        self.GetObjectsByPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetObjectsByPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.FromString,
                )
        self.GetProjectCollectionIdsByPath = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectService/GetProjectCollectionIdsByPath',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.FromString,
                )


class ObjectServiceServicer(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    def InitializeNewObject(self, request, context):
        """InitializeNewObject

        Status: STABLE

        This initializes a new object
        Initializing an object will put it in a staging area.
        Staged objects will get a separate staging id and need to be finished
        before they can be used.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUploadURL(self, request, context):
        """GetUploadURL

        Status: STABLE

        This method will return a (multi-part) url that can be used to upload a
        file to S3. Part is a optional query parameter that can be used to upload a
        part of the file / multipart upload.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDownloadURL(self, request, context):
        """GetDownloadUrl

        Status: STABLE

        This method will return a url that can be used to download a file from S3.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDownloadLinksBatch(self, request, context):
        """GetDownloadLinksBatch

        Status: BETA

        This method can be used to get download urls for multiple objects.
        The order of the returned urls will be the same as the order of the object
        ids in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDownloadLinksStream(self, request, context):
        """CreateDownloadLinksStream

        Status: BETA

        Creates a stream of objects and presigned links based on the provided query
        This can be used retrieve a large number of Objects as a stream that would
        otherwise cause issues with the connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishObjectStaging(self, request, context):
        """FinishObjectStaging

        Status: STABLE

        This method completes the staging of an object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateObject(self, request, context):
        """UpdateObject

        Status: STABLE

        Objects are immutable!
        Updating an object will create a new revision for the object
        This method will put the new revision in a staging area.
        Staged objects will get a separate staging id and need to be finished
        before they can be used.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateObjectReference(self, request, context):
        """CreateObjectReference

        Status: STABLE

        Creates a new reference of this object in another collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloneObject(self, request, context):
        """CloneObject 

        Status: STABLE

        This method clones an object and creates a copy in the same collection.
        This copy has a new id and revision and will not receive any updates from
        the original object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObject(self, request, context):
        """DeleteObject 

        Status: STABLE

        Deletes the object with the complete revision history.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObjects(self, request, context):
        """DeleteObjects

        Status: STABLE

        Deletes multiple objects at once.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectByID(self, request, context):
        """GetObjectByID 

        Status: STABLE

        gets a specific Object by ID that is associated to the
        current collection By default only the latest revision of an object will be
        returned Specify a revision_number to select an older revision With the
        optional with_url boolean a download link can automatically be requested
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjects(self, request, context):
        """GetObjects

        Status: STABLE

        GetObjects returns a (paginated) list of objects in a specific collection
        By default only the latest revisions of all objects will be shown
        This behaviour can be changed with the include_history flag
        With the optional with_url boolean a download link can automatically be
        requested for each Object This request contains a LabelOrIDQuery message,
        this is either a list of request ObjectIDs or a query filtered by Labels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectRevisions(self, request, context):
        """GetObjectRevisions

        Status: STABLE

        This returns the full list of revisions of a specified object
        With the optional with_url boolean a download link can automatically be
        requested for each Object This is by default a paginated request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestObjectRevision(self, request, context):
        """GetLatestObjectRevision

        Status: STABLE

        This returns the latest revision of a specific object
        The returned `latest` object will have a different id if the current
        object is not the latest revision
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectEndpoints(self, request, context):
        """GetObjectEndpoints

        Status: BETA

        This returns a list of endpoints
        One endpoint will be the "default" endpoint
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddLabelsToObject(self, request, context):
        """AddLabelsToObject 

        Status: STABLE

        This is a specific request to add new label(s)
        to an existing object, in contrast to UpdateObject
        this will not create a new object in the staging area
        Instead it will directly add the specified label(s) to the object
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHooksOfObject(self, request, context):
        """SetHooksOfObject

        Status: BETA

        This is a specific request to update the complete list
        of hooks for a specific object. This will not update the object
        and create a new id, instead it will overwrite all hooks of the existing
        object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferences(self, request, context):
        """GetReferences

        Status: STABLE

        Get a list of references for this object (optional) including all revisions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectPath(self, request, context):
        """GetObjectPath

        Status: BETA

        Get all object_paths for this object in a specific collection
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectPaths(self, request, context):
        """GetObjectPaths

        Status: BETA

        Get all object_paths for a specific collection
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateObjectPath(self, request, context):
        """CreateObjectPath

        Status: BETA

        Create collection_specific object_paths for an object
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetObjectPathVisibility(self, request, context):
        """SetObjectPathVisibility

        Status: BETA

        Updates the visibility setting for an object_path (hide/unhide)
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectsByPath(self, request, context):
        """GetObjectsByPath

        Status: BETA

        Gets a specific object by object_path
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectCollectionIdsByPath(self, request, context):
        """GetObjectsByPath

        Status: BETA

        Gets a specific object by object_path
        !! Paths are collection specific !!
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitializeNewObject': grpc.unary_unary_rpc_method_handler(
                    servicer.InitializeNewObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.SerializeToString,
            ),
            'GetUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUploadURL,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.SerializeToString,
            ),
            'GetDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDownloadURL,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.SerializeToString,
            ),
            'GetDownloadLinksBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDownloadLinksBatch,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.SerializeToString,
            ),
            'CreateDownloadLinksStream': grpc.unary_stream_rpc_method_handler(
                    servicer.CreateDownloadLinksStream,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.SerializeToString,
            ),
            'FinishObjectStaging': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishObjectStaging,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.SerializeToString,
            ),
            'UpdateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.SerializeToString,
            ),
            'CreateObjectReference': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateObjectReference,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.SerializeToString,
            ),
            'CloneObject': grpc.unary_unary_rpc_method_handler(
                    servicer.CloneObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.SerializeToString,
            ),
            'DeleteObject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.SerializeToString,
            ),
            'DeleteObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.SerializeToString,
            ),
            'GetObjectByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectByID,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.SerializeToString,
            ),
            'GetObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.SerializeToString,
            ),
            'GetObjectRevisions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectRevisions,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.SerializeToString,
            ),
            'GetLatestObjectRevision': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestObjectRevision,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.SerializeToString,
            ),
            'GetObjectEndpoints': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectEndpoints,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.SerializeToString,
            ),
            'AddLabelsToObject': grpc.unary_unary_rpc_method_handler(
                    servicer.AddLabelsToObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.SerializeToString,
            ),
            'SetHooksOfObject': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHooksOfObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.SerializeToString,
            ),
            'GetReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferences,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.SerializeToString,
            ),
            'GetObjectPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.SerializeToString,
            ),
            'GetObjectPaths': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectPaths,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.SerializeToString,
            ),
            'CreateObjectPath': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateObjectPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.SerializeToString,
            ),
            'SetObjectPathVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.SetObjectPathVisibility,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.SerializeToString,
            ),
            'GetObjectsByPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectsByPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.SerializeToString,
            ),
            'GetProjectCollectionIdsByPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectCollectionIdsByPath,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ObjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectService(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resources
    """

    @staticmethod
    def InitializeNewObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/InitializeNewObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.InitializeNewObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetUploadURL',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetDownloadURL',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDownloadLinksBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetDownloadLinksBatch',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetDownloadLinksBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDownloadLinksStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateDownloadLinksStream',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateDownloadLinksStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishObjectStaging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/FinishObjectStaging',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.FinishObjectStagingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/UpdateObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.UpdateObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateObjectReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateObjectReference',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloneObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CloneObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CloneObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/DeleteObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/DeleteObjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.DeleteObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectByID',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectRevisions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectRevisions',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectRevisionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestObjectRevision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetLatestObjectRevision',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetLatestObjectRevisionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectEndpoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectEndpoints',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectEndpointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddLabelsToObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/AddLabelsToObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.AddLabelsToObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHooksOfObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/SetHooksOfObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetHooksOfObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetReferences',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetReferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectPaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectPaths',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectPathsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateObjectPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/CreateObjectPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.CreateObjectPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetObjectPathVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/SetObjectPathVisibility',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.SetObjectPathVisibilityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectsByPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetObjectsByPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetObjectsByPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectCollectionIdsByPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectService/GetProjectCollectionIdsByPath',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2.GetProjectCollectionIdsByPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
