# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/info_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0aruna/api/storage/services/v1/info_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/api/annotations.proto\"\x8e\x01\n\x1bGetResourceHierarchyRequest\x12\x1f\n\x0bresource_id\x18\x01 \x01(\tR\nresourceId\x12N\n\rresource_type\x18\x02 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x0cresourceType\"\x96\x01\n\tHierarchy\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12(\n\x10object_group_ids\x18\x02 \x03(\tR\x0eobjectGroupIds\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1d\n\nproject_id\x18\x04 \x01(\tR\tprojectId\"j\n\x1cGetResourceHierarchyResponse\x12J\n\x0bhierarchies\x18\x01 \x03(\x0b\x32(.aruna.api.storage.services.v1.HierarchyR\x0bhierarchies\"\x1a\n\x18GetStorageVersionRequest\"\x92\x01\n\x0fSemanticVersion\x12%\n\x0eversion_string\x18\x01 \x01(\tR\rversionString\x12\x14\n\x05major\x18\x02 \x01(\x05R\x05major\x12\x14\n\x05minor\x18\x03 \x01(\x05R\x05minor\x12\x14\n\x05patch\x18\x04 \x01(\x05R\x05patch\x12\x16\n\x06labels\x18\x05 \x01(\tR\x06labels\"w\n\x0fLocationVersion\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12H\n\x07version\x18\x02 \x01(\x0b\x32..aruna.api.storage.services.v1.SemanticVersionR\x07version\"\x94\x01\n\x10\x43omponentVersion\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12Y\n\x10location_version\x18\x02 \x03(\x0b\x32..aruna.api.storage.services.v1.LocationVersionR\x0flocationVersion\"y\n\x19GetStorageVersionResponse\x12\\\n\x11\x63omponent_version\x18\x01 \x03(\x0b\x32/.aruna.api.storage.services.v1.ComponentVersionR\x10\x63omponentVersion\"\x19\n\x17GetStorageStatusRequest\"k\n\x0eLocationStatus\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12=\n\x06status\x18\x02 \x01(\x0e\x32%.aruna.api.storage.services.v1.StatusR\x06status\"\x90\x01\n\x0f\x43omponentStatus\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12V\n\x0flocation_status\x18\x02 \x03(\x0b\x32-.aruna.api.storage.services.v1.LocationStatusR\x0elocationStatus\"u\n\x18GetStorageStatusResponse\x12Y\n\x10\x63omponent_status\x18\x01 \x03(\x0b\x32..aruna.api.storage.services.v1.ComponentStatusR\x0f\x63omponentStatus*w\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_AVAILABLE\x10\x01\x12\x16\n\x12STATUS_UNAVAILABLE\x10\x02\x12\x13\n\x0fSTATUS_DEGRADED\x10\x03\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x04\x32\xe0\x01\n\x13ResourceInfoService\x12\xb4\x01\n\x14GetResourceHierarchy\x12:.aruna.api.storage.services.v1.GetResourceHierarchyRequest\x1a;.aruna.api.storage.services.v1.GetResourceHierarchyResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/info/resource/hierarchy\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHED2\xd6\x02\n\x12StorageInfoService\x12\xa0\x01\n\x11GetStorageVersion\x12\x37.aruna.api.storage.services.v1.GetStorageVersionRequest\x1a\x38.aruna.api.storage.services.v1.GetStorageVersionResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/info/version\x12\x9c\x01\n\x10GetStorageStatus\x12\x36.aruna.api.storage.services.v1.GetStorageStatusRequest\x1a\x37.aruna.api.storage.services.v1.GetStorageStatusResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/info/statusB\x8d\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x0bInfoServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.info_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\013InfoServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _RESOURCEINFOSERVICE._options = None
  _RESOURCEINFOSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _RESOURCEINFOSERVICE.methods_by_name['GetResourceHierarchy']._options = None
  _RESOURCEINFOSERVICE.methods_by_name['GetResourceHierarchy']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/info/resource/hierarchy'
  _STORAGEINFOSERVICE.methods_by_name['GetStorageVersion']._options = None
  _STORAGEINFOSERVICE.methods_by_name['GetStorageVersion']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/info/version'
  _STORAGEINFOSERVICE.methods_by_name['GetStorageStatus']._options = None
  _STORAGEINFOSERVICE.methods_by_name['GetStorageStatus']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/info/status'
  _STATUS._serialized_start=1564
  _STATUS._serialized_end=1683
  _GETRESOURCEHIERARCHYREQUEST._serialized_start=185
  _GETRESOURCEHIERARCHYREQUEST._serialized_end=327
  _HIERARCHY._serialized_start=330
  _HIERARCHY._serialized_end=480
  _GETRESOURCEHIERARCHYRESPONSE._serialized_start=482
  _GETRESOURCEHIERARCHYRESPONSE._serialized_end=588
  _GETSTORAGEVERSIONREQUEST._serialized_start=590
  _GETSTORAGEVERSIONREQUEST._serialized_end=616
  _SEMANTICVERSION._serialized_start=619
  _SEMANTICVERSION._serialized_end=765
  _LOCATIONVERSION._serialized_start=767
  _LOCATIONVERSION._serialized_end=886
  _COMPONENTVERSION._serialized_start=889
  _COMPONENTVERSION._serialized_end=1037
  _GETSTORAGEVERSIONRESPONSE._serialized_start=1039
  _GETSTORAGEVERSIONRESPONSE._serialized_end=1160
  _GETSTORAGESTATUSREQUEST._serialized_start=1162
  _GETSTORAGESTATUSREQUEST._serialized_end=1187
  _LOCATIONSTATUS._serialized_start=1189
  _LOCATIONSTATUS._serialized_end=1296
  _COMPONENTSTATUS._serialized_start=1299
  _COMPONENTSTATUS._serialized_end=1443
  _GETSTORAGESTATUSRESPONSE._serialized_start=1445
  _GETSTORAGESTATUSRESPONSE._serialized_end=1562
  _RESOURCEINFOSERVICE._serialized_start=1686
  _RESOURCEINFOSERVICE._serialized_end=1910
  _STORAGEINFOSERVICE._serialized_start=1913
  _STORAGEINFOSERVICE._serialized_end=2255
# @@protoc_insertion_point(module_scope)
