# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/service_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import auth_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_auth__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;aruna/api/storage/services/v1/service_account_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a&aruna/api/storage/models/v1/auth.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x99\x01\n\x1b\x43reateServiceAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12G\n\npermission\x18\x03 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"\xb2\x01\n\x0eServiceAccount\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12G\n\npermission\x18\x04 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"v\n\x1c\x43reateServiceAccountResponse\x12V\n\x0fservice_account\x18\x01 \x01(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0eserviceAccount\"\x85\x02\n CreateServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12G\n\npermission\x18\x05 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\"\x80\x01\n!CreateServiceAccountTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\x12!\n\x0ctoken_secret\x18\x02 \x01(\tR\x0btokenSecret\"\x9b\x01\n#EditServiceAccountPermissionRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12N\n\x0enew_permission\x18\x02 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\rnewPermission\"~\n$EditServiceAccountPermissionResponse\x12V\n\x0fservice_account\x18\x01 \x01(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0eserviceAccount\"`\n\x1dGetServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x19\n\x08token_id\x18\x02 \x01(\tR\x07tokenId\"Z\n\x1eGetServiceAccountTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"F\n\x1eGetServiceAccountTokensRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"[\n\x1fGetServiceAccountTokensResponse\x12\x38\n\x05token\x18\x01 \x03(\x0b\x32\".aruna.api.storage.models.v1.TokenR\x05token\"C\n\"GetServiceAccountsByProjectRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"w\n#GetServiceAccountsByProjectResponse\x12P\n\x0csvc_accounts\x18\x01 \x03(\x0b\x32-.aruna.api.storage.services.v1.ServiceAccountR\x0bsvcAccounts\"c\n DeleteServiceAccountTokenRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\x12\x19\n\x08token_id\x18\x02 \x01(\tR\x07tokenId\"#\n!DeleteServiceAccountTokenResponse\"I\n!DeleteServiceAccountTokensRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"$\n\"DeleteServiceAccountTokensResponse\"C\n\x1b\x44\x65leteServiceAccountRequest\x12$\n\x0esvc_account_id\x18\x01 \x01(\tR\x0csvcAccountId\"\x1e\n\x1c\x44\x65leteServiceAccountResponse2\x95\x0f\n\x15ServiceAccountService\x12\xaf\x01\n\x14\x43reateServiceAccount\x12:.aruna.api.storage.services.v1.CreateServiceAccountRequest\x1a;.aruna.api.storage.services.v1.CreateServiceAccountResponse\"\x1e\x82\xd3\xe4\x93\x02\x18:\x01*\"\x13/v1/service_account\x12\xd5\x01\n\x19\x43reateServiceAccountToken\x12?.aruna.api.storage.services.v1.CreateServiceAccountTokenRequest\x1a@.aruna.api.storage.services.v1.CreateServiceAccountTokenResponse\"5\x82\xd3\xe4\x93\x02/:\x01*\"*/v1/service_account/{svc_account_id}/token\x12\xe4\x01\n\x1c\x45\x64itServiceAccountPermission\x12\x42.aruna.api.storage.services.v1.EditServiceAccountPermissionRequest\x1a\x43.aruna.api.storage.services.v1.EditServiceAccountPermissionResponse\";\x82\xd3\xe4\x93\x02\x35:\x01*\x1a\x30/v1/service_account/{svc_account_id}/permissions\x12\xd4\x01\n\x16GetServiceAccountToken\x12<.aruna.api.storage.services.v1.GetServiceAccountTokenRequest\x1a=.aruna.api.storage.services.v1.GetServiceAccountTokenResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/service_account/{svc_account_id}/token/{token_id}\x12\xcd\x01\n\x17GetServiceAccountTokens\x12=.aruna.api.storage.services.v1.GetServiceAccountTokensRequest\x1a>.aruna.api.storage.services.v1.GetServiceAccountTokensResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/service_account/{svc_account_id}/tokens\x12\xd6\x01\n\x1bGetServiceAccountsByProject\x12\x41.aruna.api.storage.services.v1.GetServiceAccountsByProjectRequest\x1a\x42.aruna.api.storage.services.v1.GetServiceAccountsByProjectResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/service_account/project/{project_id}\x12\xdd\x01\n\x19\x44\x65leteServiceAccountToken\x12?.aruna.api.storage.services.v1.DeleteServiceAccountTokenRequest\x1a@.aruna.api.storage.services.v1.DeleteServiceAccountTokenResponse\"=\x82\xd3\xe4\x93\x02\x37*5/v1/service_account/{svc_account_id}/token/{token_id}\x12\xd6\x01\n\x1a\x44\x65leteServiceAccountTokens\x12@.aruna.api.storage.services.v1.DeleteServiceAccountTokensRequest\x1a\x41.aruna.api.storage.services.v1.DeleteServiceAccountTokensResponse\"3\x82\xd3\xe4\x93\x02-*+/v1/service_account/{svc_account_id}/tokens\x12\xbd\x01\n\x14\x44\x65leteServiceAccount\x12:.aruna.api.storage.services.v1.DeleteServiceAccountRequest\x1a;.aruna.api.storage.services.v1.DeleteServiceAccountResponse\",\x82\xd3\xe4\x93\x02&*$/v1/service_account/{svc_account_id}\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHEDB\x97\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x15ServiceAccountServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.service_account_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\025ServiceAccountServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _SERVICEACCOUNTSERVICE._options = None
  _SERVICEACCOUNTSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccount']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccount']._serialized_options = b'\202\323\344\223\002\030:\001*\"\023/v1/service_account'
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['CreateServiceAccountToken']._serialized_options = b'\202\323\344\223\002/:\001*\"*/v1/service_account/{svc_account_id}/token'
  _SERVICEACCOUNTSERVICE.methods_by_name['EditServiceAccountPermission']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['EditServiceAccountPermission']._serialized_options = b'\202\323\344\223\0025:\001*\0320/v1/service_account/{svc_account_id}/permissions'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountToken']._serialized_options = b'\202\323\344\223\0027\0225/v1/service_account/{svc_account_id}/token/{token_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountTokens']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountTokens']._serialized_options = b'\202\323\344\223\002-\022+/v1/service_account/{svc_account_id}/tokens'
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountsByProject']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['GetServiceAccountsByProject']._serialized_options = b'\202\323\344\223\002*\022(/v1/service_account/project/{project_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountToken']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountToken']._serialized_options = b'\202\323\344\223\0027*5/v1/service_account/{svc_account_id}/token/{token_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountTokens']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccountTokens']._serialized_options = b'\202\323\344\223\002-*+/v1/service_account/{svc_account_id}/tokens'
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccount']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['DeleteServiceAccount']._serialized_options = b'\202\323\344\223\002&*$/v1/service_account/{svc_account_id}'
  _CREATESERVICEACCOUNTREQUEST._serialized_start=227
  _CREATESERVICEACCOUNTREQUEST._serialized_end=380
  _SERVICEACCOUNT._serialized_start=383
  _SERVICEACCOUNT._serialized_end=561
  _CREATESERVICEACCOUNTRESPONSE._serialized_start=563
  _CREATESERVICEACCOUNTRESPONSE._serialized_end=681
  _CREATESERVICEACCOUNTTOKENREQUEST._serialized_start=684
  _CREATESERVICEACCOUNTTOKENREQUEST._serialized_end=945
  _CREATESERVICEACCOUNTTOKENRESPONSE._serialized_start=948
  _CREATESERVICEACCOUNTTOKENRESPONSE._serialized_end=1076
  _EDITSERVICEACCOUNTPERMISSIONREQUEST._serialized_start=1079
  _EDITSERVICEACCOUNTPERMISSIONREQUEST._serialized_end=1234
  _EDITSERVICEACCOUNTPERMISSIONRESPONSE._serialized_start=1236
  _EDITSERVICEACCOUNTPERMISSIONRESPONSE._serialized_end=1362
  _GETSERVICEACCOUNTTOKENREQUEST._serialized_start=1364
  _GETSERVICEACCOUNTTOKENREQUEST._serialized_end=1460
  _GETSERVICEACCOUNTTOKENRESPONSE._serialized_start=1462
  _GETSERVICEACCOUNTTOKENRESPONSE._serialized_end=1552
  _GETSERVICEACCOUNTTOKENSREQUEST._serialized_start=1554
  _GETSERVICEACCOUNTTOKENSREQUEST._serialized_end=1624
  _GETSERVICEACCOUNTTOKENSRESPONSE._serialized_start=1626
  _GETSERVICEACCOUNTTOKENSRESPONSE._serialized_end=1717
  _GETSERVICEACCOUNTSBYPROJECTREQUEST._serialized_start=1719
  _GETSERVICEACCOUNTSBYPROJECTREQUEST._serialized_end=1786
  _GETSERVICEACCOUNTSBYPROJECTRESPONSE._serialized_start=1788
  _GETSERVICEACCOUNTSBYPROJECTRESPONSE._serialized_end=1907
  _DELETESERVICEACCOUNTTOKENREQUEST._serialized_start=1909
  _DELETESERVICEACCOUNTTOKENREQUEST._serialized_end=2008
  _DELETESERVICEACCOUNTTOKENRESPONSE._serialized_start=2010
  _DELETESERVICEACCOUNTTOKENRESPONSE._serialized_end=2045
  _DELETESERVICEACCOUNTTOKENSREQUEST._serialized_start=2047
  _DELETESERVICEACCOUNTTOKENSREQUEST._serialized_end=2120
  _DELETESERVICEACCOUNTTOKENSRESPONSE._serialized_start=2122
  _DELETESERVICEACCOUNTTOKENSRESPONSE._serialized_end=2158
  _DELETESERVICEACCOUNTREQUEST._serialized_start=2160
  _DELETESERVICEACCOUNTREQUEST._serialized_end=2227
  _DELETESERVICEACCOUNTRESPONSE._serialized_start=2229
  _DELETESERVICEACCOUNTRESPONSE._serialized_end=2259
  _SERVICEACCOUNTSERVICE._serialized_start=2262
  _SERVICEACCOUNTSERVICE._serialized_end=4203
# @@protoc_insertion_point(module_scope)
