# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.services.v1 import object_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_object__service__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aruna/api/internal/v1/proxy.proto\x12\x15\x61runa.api.internal.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\x32\x61runa/api/storage/services/v1/object_service.proto\x1a\x1bgoogle/api/visibility.proto\"\xff\x01\n\x08Location\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32#.aruna.api.internal.v1.LocationTypeR\x04type\x12\x16\n\x06\x62ucket\x18\x02 \x01(\tR\x06\x62ucket\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1f\n\x0b\x65ndpoint_id\x18\x04 \x01(\tR\nendpointId\x12#\n\ris_compressed\x18\x05 \x01(\x08R\x0cisCompressed\x12!\n\x0cis_encrypted\x18\x06 \x01(\x08R\x0bisEncrypted\x12%\n\x0e\x65ncryption_key\x18\x07 \x01(\tR\rencryptionKey\"?\n\x08PartETag\x12\x1f\n\x0bpart_number\x18\x01 \x01(\x03R\npartNumber\x12\x12\n\x04\x65tag\x18\x02 \x01(\tR\x04\x65tag\"r\n\x1aInitMultipartUploadRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\":\n\x1bInitMultipartUploadResponse\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\"\xd1\x01\n\x1c\x46inishMultipartUploadRequest\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1b\n\tobject_id\x18\x03 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x04 \x01(\tR\x0c\x63ollectionId\x12>\n\npart_etags\x18\x05 \x03(\x0b\x32\x1f.aruna.api.internal.v1.PartETagR\tpartEtags\"\x1f\n\x1d\x46inishMultipartUploadResponse\"R\n\x13\x44\x65leteObjectRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\"\x16\n\x14\x44\x65leteObjectResponse\"\xf8\x01\n\x15\x46inalizeObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12;\n\x08location\x18\x03 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x39\n\x06hashes\x18\x04 \x03(\x0b\x32!.aruna.api.storage.models.v1.HashR\x06hashes\x12%\n\x0e\x63ontent_length\x18\x05 \x01(\x03R\rcontentLength\"\x18\n\x16\x46inalizeObjectResponse\"j\n\x1fGetOrCreateEncryptionKeyRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04hash\x18\x02 \x01(\tR\x04hash\x12\x1f\n\x0b\x65ndpoint_id\x18\x03 \x01(\tR\nendpointId\"c\n GetOrCreateEncryptionKeyResponse\x12%\n\x0e\x65ncryption_key\x18\x01 \x01(\tR\rencryptionKey\x12\x18\n\x07\x63reated\x18\x02 \x01(\x08R\x07\x63reated\"\xd3\x01\n\x1eGetOrCreateObjectByPathRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1d\n\naccess_key\x18\x02 \x01(\tR\taccessKey\x12\x42\n\x06object\x18\x03 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12\x19\n\x08get_only\x18\x04 \x01(\x08R\x07getOnly\x12\x1f\n\x0b\x65ndpoint_id\x18\x05 \x01(\tR\nendpointId\"\xa7\x02\n\x1fGetOrCreateObjectByPathResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x44\n\tdataclass\x18\x03 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12\x39\n\x06hashes\x18\x04 \x03(\x0b\x32!.aruna.api.storage.models.v1.HashR\x06hashes\x12\'\n\x0frevision_number\x18\x05 \x01(\x03R\x0erevisionNumber\x12\x18\n\x07\x63reated\x18\x06 \x01(\x08R\x07\x63reated\"\x8f\x01\n\x18GetObjectLocationRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1f\n\x0brevision_id\x18\x02 \x01(\tR\nrevisionId\x12\x1d\n\naccess_key\x18\x03 \x01(\tR\taccessKey\x12\x1f\n\x0b\x65ndpoint_id\x18\x04 \x01(\tR\nendpointId\"\x95\x01\n\x19GetObjectLocationResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12;\n\x08location\x18\x02 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\"U\n\x1cGetCollectionByBucketRequest\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12\x1d\n\naccess_key\x18\x02 \x01(\tR\taccessKey\"c\n\x1dGetCollectionByBucketResponse\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId*[\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10LOCATION_TYPE_S3\x10\x01\x12\x16\n\x12LOCATION_TYPE_FILE\x10\x02\x32\x9a\x03\n\x14InternalProxyService\x12~\n\x13InitMultipartUpload\x12\x31.aruna.api.internal.v1.InitMultipartUploadRequest\x1a\x32.aruna.api.internal.v1.InitMultipartUploadResponse\"\x00\x12\x84\x01\n\x15\x46inishMultipartUpload\x12\x33.aruna.api.internal.v1.FinishMultipartUploadRequest\x1a\x34.aruna.api.internal.v1.FinishMultipartUploadResponse\"\x00\x12i\n\x0c\x44\x65leteObject\x12*.aruna.api.internal.v1.DeleteObjectRequest\x1a+.aruna.api.internal.v1.DeleteObjectResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL2\xbf\x05\n\x1cInternalProxyNotifierService\x12\x8a\x01\n\x17GetOrCreateObjectByPath\x12\x35.aruna.api.internal.v1.GetOrCreateObjectByPathRequest\x1a\x36.aruna.api.internal.v1.GetOrCreateObjectByPathResponse\"\x00\x12o\n\x0e\x46inalizeObject\x12,.aruna.api.internal.v1.FinalizeObjectRequest\x1a-.aruna.api.internal.v1.FinalizeObjectResponse\"\x00\x12\x8d\x01\n\x18GetOrCreateEncryptionKey\x12\x36.aruna.api.internal.v1.GetOrCreateEncryptionKeyRequest\x1a\x37.aruna.api.internal.v1.GetOrCreateEncryptionKeyResponse\"\x00\x12x\n\x11GetObjectLocation\x12/.aruna.api.internal.v1.GetObjectLocationRequest\x1a\x30.aruna.api.internal.v1.GetObjectLocationResponse\"\x00\x12\x84\x01\n\x15GetCollectionByBucket\x12\x33.aruna.api.internal.v1.GetCollectionByBucketRequest\x1a\x34.aruna.api.internal.v1.GetCollectionByBucketResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALPROXYSERVICE._options = None
  _INTERNALPROXYSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _INTERNALPROXYNOTIFIERSERVICE._options = None
  _INTERNALPROXYNOTIFIERSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _LOCATIONTYPE._serialized_start=2519
  _LOCATIONTYPE._serialized_end=2610
  _LOCATION._serialized_start=184
  _LOCATION._serialized_end=439
  _PARTETAG._serialized_start=441
  _PARTETAG._serialized_end=504
  _INITMULTIPARTUPLOADREQUEST._serialized_start=506
  _INITMULTIPARTUPLOADREQUEST._serialized_end=620
  _INITMULTIPARTUPLOADRESPONSE._serialized_start=622
  _INITMULTIPARTUPLOADRESPONSE._serialized_end=680
  _FINISHMULTIPARTUPLOADREQUEST._serialized_start=683
  _FINISHMULTIPARTUPLOADREQUEST._serialized_end=892
  _FINISHMULTIPARTUPLOADRESPONSE._serialized_start=894
  _FINISHMULTIPARTUPLOADRESPONSE._serialized_end=925
  _DELETEOBJECTREQUEST._serialized_start=927
  _DELETEOBJECTREQUEST._serialized_end=1009
  _DELETEOBJECTRESPONSE._serialized_start=1011
  _DELETEOBJECTRESPONSE._serialized_end=1033
  _FINALIZEOBJECTREQUEST._serialized_start=1036
  _FINALIZEOBJECTREQUEST._serialized_end=1284
  _FINALIZEOBJECTRESPONSE._serialized_start=1286
  _FINALIZEOBJECTRESPONSE._serialized_end=1310
  _GETORCREATEENCRYPTIONKEYREQUEST._serialized_start=1312
  _GETORCREATEENCRYPTIONKEYREQUEST._serialized_end=1418
  _GETORCREATEENCRYPTIONKEYRESPONSE._serialized_start=1420
  _GETORCREATEENCRYPTIONKEYRESPONSE._serialized_end=1519
  _GETORCREATEOBJECTBYPATHREQUEST._serialized_start=1522
  _GETORCREATEOBJECTBYPATHREQUEST._serialized_end=1733
  _GETORCREATEOBJECTBYPATHRESPONSE._serialized_start=1736
  _GETORCREATEOBJECTBYPATHRESPONSE._serialized_end=2031
  _GETOBJECTLOCATIONREQUEST._serialized_start=2034
  _GETOBJECTLOCATIONREQUEST._serialized_end=2177
  _GETOBJECTLOCATIONRESPONSE._serialized_start=2180
  _GETOBJECTLOCATIONRESPONSE._serialized_end=2329
  _GETCOLLECTIONBYBUCKETREQUEST._serialized_start=2331
  _GETCOLLECTIONBYBUCKETREQUEST._serialized_end=2416
  _GETCOLLECTIONBYBUCKETRESPONSE._serialized_start=2418
  _GETCOLLECTIONBYBUCKETRESPONSE._serialized_end=2517
  _INTERNALPROXYSERVICE._serialized_start=2613
  _INTERNALPROXYSERVICE._serialized_end=3023
  _INTERNALPROXYNOTIFIERSERVICE._serialized_start=3026
  _INTERNALPROXYNOTIFIERSERVICE._serialized_end=3729
# @@protoc_insertion_point(module_scope)
