# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/models/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'aruna/api/storage/models/v1/query.proto\x12\x1b\x61runa.api.storage.models.v1\x1a(aruna/api/storage/models/v1/models.proto\"G\n\x0bPageRequest\x12\x1b\n\tlast_uuid\x18\x01 \x01(\tR\x08lastUuid\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\"\x85\x01\n\x0bLabelFilter\x12=\n\x06labels\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12\x1a\n\tand_or_or\x18\x02 \x01(\x08R\x07\x61ndOrOr\x12\x1b\n\tkeys_only\x18\x03 \x01(\x08R\x08keysOnly\"d\n\x0eLabelOrIDQuery\x12@\n\x06labels\x18\x01 \x01(\x0b\x32(.aruna.api.storage.models.v1.LabelFilterR\x06labels\x12\x10\n\x03ids\x18\x02 \x03(\tR\x03idsB<Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.models.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1'
  _PAGEREQUEST._serialized_start=114
  _PAGEREQUEST._serialized_end=185
  _LABELFILTER._serialized_start=188
  _LABELFILTER._serialized_end=321
  _LABELORIDQUERY._serialized_start=323
  _LABELORIDQUERY._serialized_end=423
# @@protoc_insertion_point(module_scope)
