# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/collection_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6aruna/api/storage/services/v1/collection_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\x86\x03\n\x1a\x43reateNewCollectionRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x06 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x44\n\tdataclass\x18\x07 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\"B\n\x1b\x43reateNewCollectionResponse\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\"?\n\x18GetCollectionByIDRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\"l\n\x19GetCollectionByIDResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"\xdd\x01\n\x15GetCollectionsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12X\n\x12label_or_id_filter\x18\x02 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\x0flabelOrIdFilter\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\"l\n\x16GetCollectionsResponse\x12R\n\x0b\x63ollections\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.CollectionOverviewsR\x0b\x63ollections\"\xc9\x03\n\x17UpdateCollectionRequest\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x07 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x44\n\tdataclass\x18\x08 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12>\n\x07version\x18\t \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionR\x07version\"k\n\x18UpdateCollectionResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"\x82\x01\n\x1bPinCollectionVersionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12>\n\x07version\x18\x02 \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionR\x07version\"o\n\x1cPinCollectionVersionResponse\x12O\n\ncollection\x18\x01 \x01(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\ncollection\"T\n\x17\x44\x65leteCollectionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"\x1a\n\x18\x44\x65leteCollectionResponse2\xb7\x08\n\x11\x43ollectionService\x12\xa7\x01\n\x13\x43reateNewCollection\x12\x39.aruna.api.storage.services.v1.CreateNewCollectionRequest\x1a:.aruna.api.storage.services.v1.CreateNewCollectionResponse\"\x19\x82\xd3\xe4\x93\x02\x13:\x01*\"\x0e/v1/collection\x12\xae\x01\n\x11GetCollectionByID\x12\x37.aruna.api.storage.services.v1.GetCollectionByIDRequest\x1a\x38.aruna.api.storage.services.v1.GetCollectionByIDResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/collection/{collection_id}\x12\xa3\x01\n\x0eGetCollections\x12\x34.aruna.api.storage.services.v1.GetCollectionsRequest\x1a\x35.aruna.api.storage.services.v1.GetCollectionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/collections/{project_id}\x12\xae\x01\n\x10UpdateCollection\x12\x36.aruna.api.storage.services.v1.UpdateCollectionRequest\x1a\x37.aruna.api.storage.services.v1.UpdateCollectionResponse\")\x82\xd3\xe4\x93\x02#:\x01*\x1a\x1e/v1/collection/{collection_id}\x12\xbe\x01\n\x14PinCollectionVersion\x12:.aruna.api.storage.services.v1.PinCollectionVersionRequest\x1a;.aruna.api.storage.services.v1.PinCollectionVersionResponse\"-\x82\xd3\xe4\x93\x02\':\x01*\"\"/v1/collection/{collection_id}/pin\x12\xae\x01\n\x10\x44\x65leteCollection\x12\x36.aruna.api.storage.services.v1.DeleteCollectionRequest\x1a\x37.aruna.api.storage.services.v1.DeleteCollectionResponse\")\x82\xd3\xe4\x93\x02#:\x01**\x1e/v1/collection/{collection_id}B\x93\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x11\x43ollectionServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.collection_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\021CollectionServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _COLLECTIONSERVICE.methods_by_name['CreateNewCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['CreateNewCollection']._serialized_options = b'\202\323\344\223\002\023:\001*\"\016/v1/collection'
  _COLLECTIONSERVICE.methods_by_name['GetCollectionByID']._options = None
  _COLLECTIONSERVICE.methods_by_name['GetCollectionByID']._serialized_options = b'\202\323\344\223\002 \022\036/v1/collection/{collection_id}'
  _COLLECTIONSERVICE.methods_by_name['GetCollections']._options = None
  _COLLECTIONSERVICE.methods_by_name['GetCollections']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/collections/{project_id}'
  _COLLECTIONSERVICE.methods_by_name['UpdateCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['UpdateCollection']._serialized_options = b'\202\323\344\223\002#:\001*\032\036/v1/collection/{collection_id}'
  _COLLECTIONSERVICE.methods_by_name['PinCollectionVersion']._options = None
  _COLLECTIONSERVICE.methods_by_name['PinCollectionVersion']._serialized_options = b'\202\323\344\223\002\':\001*\"\"/v1/collection/{collection_id}/pin'
  _COLLECTIONSERVICE.methods_by_name['DeleteCollection']._options = None
  _COLLECTIONSERVICE.methods_by_name['DeleteCollection']._serialized_options = b'\202\323\344\223\002#:\001**\036/v1/collection/{collection_id}'
  _CREATENEWCOLLECTIONREQUEST._serialized_start=203
  _CREATENEWCOLLECTIONREQUEST._serialized_end=593
  _CREATENEWCOLLECTIONRESPONSE._serialized_start=595
  _CREATENEWCOLLECTIONRESPONSE._serialized_end=661
  _GETCOLLECTIONBYIDREQUEST._serialized_start=663
  _GETCOLLECTIONBYIDREQUEST._serialized_end=726
  _GETCOLLECTIONBYIDRESPONSE._serialized_start=728
  _GETCOLLECTIONBYIDRESPONSE._serialized_end=836
  _GETCOLLECTIONSREQUEST._serialized_start=839
  _GETCOLLECTIONSREQUEST._serialized_end=1060
  _GETCOLLECTIONSRESPONSE._serialized_start=1062
  _GETCOLLECTIONSRESPONSE._serialized_end=1170
  _UPDATECOLLECTIONREQUEST._serialized_start=1173
  _UPDATECOLLECTIONREQUEST._serialized_end=1630
  _UPDATECOLLECTIONRESPONSE._serialized_start=1632
  _UPDATECOLLECTIONRESPONSE._serialized_end=1739
  _PINCOLLECTIONVERSIONREQUEST._serialized_start=1742
  _PINCOLLECTIONVERSIONREQUEST._serialized_end=1872
  _PINCOLLECTIONVERSIONRESPONSE._serialized_start=1874
  _PINCOLLECTIONVERSIONRESPONSE._serialized_end=1985
  _DELETECOLLECTIONREQUEST._serialized_start=1987
  _DELETECOLLECTIONREQUEST._serialized_end=2071
  _DELETECOLLECTIONRESPONSE._serialized_start=2073
  _DELETECOLLECTIONRESPONSE._serialized_end=2099
  _COLLECTIONSERVICE._serialized_start=2102
  _COLLECTIONSERVICE._serialized_end=3181
# @@protoc_insertion_point(module_scope)
